@@ -5,23 +5,26 @@
 #include <R_ext/Lapack.h>
 
 
-extern SEXP dupRowNumMat(SEXP, SEXP);
 extern SEXP getGlmBias(SEXP, SEXP, SEXP, SEXP);
 extern void initQRdecomp(int*, int*);
 extern void finalQRdecomp(void);
 
 static R_CallMethodDef callMethods[]  = {
-  {"dupRowNumMat", (DL_FUNC) &dupRowNumMat, 2},
   {"getGlmBias", (DL_FUNC) &getGlmBias, 4},
   {NULL, NULL, 0}
 };
+static R_NativePrimitiveArgType initQRdecomp_t[] = {
+    INTSXP, INTSXP
+};
 static R_CMethodDef cMethods[] = {
-  {"initQRdecomp", (DL_FUNC) &initQRdecomp, 2},
-  {"finalQRdecomp", (DL_FUNC) &finalQRdecomp, 0},
-  {NULL, NULL, 0}
+  {"initQRdecomp", (DL_FUNC) &initQRdecomp, 2, initQRdecomp_t},
+  {"finalQRdecomp", (DL_FUNC) &finalQRdecomp, 0, NULL},
+  {NULL, NULL, 0, NULL}
 };
 
 void R_init_QuasiSeq(DllInfo *info)
 {
    R_registerRoutines(info, cMethods, callMethods, NULL, NULL);
+  R_useDynamicSymbols(info, FALSE);
+  R_forceSymbols(info, TRUE); 
 }
